zlib: Data compression library
==============================

Description
-----------

Massively Spiffy Yet Delicately Unobtrusive Compression Library (Also
Free, Not to Mention Unencumbered by Patents)

License
-------

-  Modified BSD.


Upstream Contact
----------------

-  http://www.zlib.net/

Special Update/Build Instructions
---------------------------------

Patches
~~~~~~~

-  cygwin_symbols.patch: remove undefined symbols on Cygwin.
